from .map import Map
from .layer import LayerGroup, FeatureGroup
from .layer.tile import TileLayer
from .layer.marker import Marker
from .layer.vector import Circle, CircleMarker, Polygon, Polyline, Rectangle
from .control import Control

class L:
    """
    Leaflet namespace that holds reference to all the leaflet objects
    """
    map = Map
    tileLayer = TileLayer
    marker = Marker
    circleMarker = CircleMarker
    polyline = Polyline
    polygon = Polygon
    rectangle = Rectangle
    circle = Circle
    layerGroup = LayerGroup
    featureGroup = FeatureGroup
    control = Control




"""
Copyright ©2018 Skylark Drones Private Limited, All Rights Reserved

Bringing Leaflet maps to PyQt.
"""

__author__ = 'Samarth Hattangady <samarth@skylarkdrones.com>'
__version__ = '0.2.1'

from .mapwidget import MapWidget
from .leaflet import L



from ..layer import Layer

class Marker(Layer):
    def __init__(self, latLng, options=None):
        super().__init__()
        self.latLng = latLng
        self.options = options
        self._initJs()

    def _initJs(self):
        leafletJsObject = 'L.marker({latLng}'.format(latLng=self.latLng)
        if self.options:
            leafletJsObject += ', {options}'.format(options=self.options)
        leafletJsObject += ')'
        self._createJsObject(leafletJsObject)

    def setLatLng(self, latLng):
        js = '{layerName}.setLatLng({latLng})'.format(
                layerName=self._layerName, latLng=latLng)
        self.runJavaScript(js)

    def setOpacity(self, opacity):
        js = '{layerName}.setOpacity({latLng})'.format(
                layerName=self._layerName, opacity=opacity)
        self.runJavaScript(js)



from distutils.core import setup
setup(
  name = 'pyqtlet',
  packages = ['pyqtlet', 
      'pyqtlet.web', 
      'pyqtlet.web.modules.leaflet', 
      'pyqtlet.web.modules.leaflet.images', 
      'pyqtlet.web.modules.leafletdraw', 
      'pyqtlet.web.modules.leafletdraw.draw', 
      'pyqtlet.web.modules.leafletdraw.draw.handler', 
      'pyqtlet.web.modules.leafletdraw.edit', 
      'pyqtlet.web.modules.leafletdraw.edit.handler', 
      'pyqtlet.web.modules.leafletdraw.images', 
      'pyqtlet.web.modules.leafletdraw.ext', 
      'pyqtlet.leaflet', 
      'pyqtlet.leaflet.control',
      'pyqtlet.leaflet.core',
      'pyqtlet.leaflet.layer',
      'pyqtlet.leaflet.layer.marker',
      'pyqtlet.leaflet.layer.tile',
      'pyqtlet.leaflet.layer.vector',
      'pyqtlet.leaflet.map',
      ],
  package_data = {'pyqtlet.web':['*'], 'pyqtlet.web.modules':['*'],
      'pyqtlet.web.modules.leaflet': ['*'], 'pyqtlet.web.modules.leaflet.images':['*'],
      'pyqtlet.web.modules.leafletdraw':['*'], 'pyqtlet.web.modules.leafletdraw.draw': ['*'],
      'pyqtlet.web.modules.leafletdraw.draw.handler': ['*'],
      'pyqtlet.web.modules.leafletdraw.edit': ['*'],
      'pyqtlet.web.modules.leafletdraw.edit.handler': ['*'],
      'pyqtlet.web.modules.leafletdraw.images': ['*'],
      'pyqtlet.web.modules.leafletdraw.ext': ['*'],
      },
  version = '0.2.3',
  description = 'Bringing leaflet maps to PyQt',
  author = 'Samarth Hattangady',
  author_email = 'samhattangady@gmail.com',
  url = 'https://github.com/skylarkdrones/pyqtlet',
  keywords = ['leaflet', 'pyqt', 'maps'],
  classifiers = [],
)
